@@ -1,6 +1,6 @@
 // Copyright 2008-present Contributors to the OpenImageIO project.
 // SPDX-License-Identifier: BSD-3-Clause
-// https://github.com/OpenImageIO/oiio/blob/master/LICENSE.md
+// https://github.com/OpenImageIO/oiio
 
 #pragma once
 
@@ -12,8 +12,6 @@
 #include <OpenImageIO/typedesc.h>
 #include <OpenImageIO/ustring.h>
 
-#include <OpenEXR/ImathMatrix.h> /* because we need M44f */
-
 
 OIIO_NAMESPACE_BEGIN
 
@@ -36,7 +34,8 @@ public:
     // Convert a single 3-color
     void apply(float* data)
     {
-        apply((float*)data, 1, 1, 3, sizeof(float), 0, 0);
+        apply((float*)data, 1, 1, 3, sizeof(float), 3 * sizeof(float),
+              3 * sizeof(float));
     }
 };
 
@@ -87,12 +86,15 @@ public:
 
     /// Has an error string occurred?
     /// (This will not affect the error state.)
+    bool has_error() const;
+
+    /// DEPRECATED(2.4), old name for has_error().
     bool error() const;
 
-    /// This routine will return the error string (and clear any error
-    /// flags).  If no error has occurred since the last time geterror()
-    /// was called, it will return an empty string.
-    std::string geterror();
+    /// This routine will return the error string (and by default, clear any
+    /// error flags).  If no error has occurred since the last time
+    /// geterror() was called, it will return an empty string.
+    std::string geterror(bool clear = true);
 
     /// Get the number of ColorSpace(s) defined in this configuration
     int getNumColorSpaces() const;
@@ -266,16 +268,22 @@ public:
     ColorProcessorHandle createMatrixTransform(const Imath::M44f& M,
                                                bool inverse = false) const;
 
+    /// Given a filepath, ask OCIO what color space it thinks the file
+    /// should be, based on how the name matches file naming rules in the
+    /// OCIO config.  (This is mostly a wrapper around OCIO's
+    /// ColorConfig::getColorSpaceFromSFilepath.)
+    string_view getColorSpaceFromFilepath(string_view str) const;
+
     /// Given a string (like a filename), look for the longest, right-most
     /// colorspace substring that appears. Returns "" if no such color space
-    /// is found. (This is just a wrapper around OCIO's
-    /// ColorConfig::parseColorSpaceFromString.)
+    /// is found.
     string_view parseColorSpaceFromString(string_view str) const;
 
     /// Return a filename or other identifier for the config we're using.
     std::string configname() const;
 
     // DEPRECATED(1.9) -- no longer necessary, because it's a shared ptr
+    OIIO_DEPRECATED("no longer necessary (1.9)")
     static void deleteColorProcessor(const ColorProcessorHandle& /*processor*/)
     {
     }
@@ -283,6 +291,10 @@ public:
     /// Return if OpenImageIO was built with OCIO support
     static bool supportsOpenColorIO();
 
+    /// Return the hex OCIO version (maj<<24 + min<<16 + patch), or 0 if no
+    /// OCIO support is available.
+    static int OpenColorIO_version_hex();
+
 private:
     ColorConfig(const ColorConfig&) = delete;
     ColorConfig& operator=(const ColorConfig&) = delete;
